@@ -4,7 +4,7 @@ class Temperature(Base):
     def __init__(self, celsius = None, fahrenheit = None, kelvin = None):
         if not is_none(celsius):
             self.celsius = celsius
-            self.fahrenheit = (32 * 9/5) + 32
+            self.fahrenheit = (celsius * 9/5) + 32
             self.kelvin = celsius + 273.15
         elif not is_none(fahrenheit):
             self.celsius = (fahrenheit - 32) * 5/9
